pub struct DelegateAgentTool { /* private fields */ }Expand description
Tool for delegating tasks to other agents
This tool allows a supervisor agent to delegate specific tasks to specialized worker agents and receive their responses.
Implementations
Sourceimpl DelegateAgentTool
impl DelegateAgentTool
Sourcepub fn new(registry: Arc<AgentRegistry>) -> Self
pub fn new(registry: Arc<AgentRegistry>) -> Self
Create a new delegation tool
Sourcepub fn with_timeout(self, timeout: Duration) -> Self
pub fn with_timeout(self, timeout: Duration) -> Self
Set timeout for waiting for agent response